@@ -87,14 +87,14 @@ class MultiXgboostModel(BaseModel):
             df2.dropna(axis=0, how='any', inplace=True)
             x = df2[df2.columns[1:-1 - len(cols)]].values
             y = df2[cols].values
-            return x, y
+            return df2, x, y
         else:
             df2.dropna(axis=0, how='any', inplace=True)
             x = df2[df2.columns[1:]].values
-            return x
+            return df2, x
 
     def train(self, df, *args, **kwargs):
-        x, y = self.solve(df)
+        df2, x, y = self.solve(df)
 
         from sklearn.multiclass import OneVsRestClassifier
         from xgboost import XGBClassifier
@@ -104,5 +104,5 @@ class MultiXgboostModel(BaseModel):
         self.model.fit(x, y)
 
     def predict(self, df, *args, **kwargs):
-        x = self.solve(df, train=False)
-        return self.model.predict(x)
+        df2, x = self.solve(df, train=False)
+        return df2, self.model.predict(x)
